@@ -1,7 +1,7 @@
 #
-# $Id: VOS.pm,v 5.2 2003/11/13 20:59:41 wpm Exp $
+# $Id: VOS.pm,v 8.2 2004/08/24 14:29:02 wpm Exp $
 #
-# (c) 2003 Morgan Stanley and Co.
+# (c) 2003-2004 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -23,7 +23,7 @@ use AFS::Object::Partition;
 use AFS::Object::Transaction;
 
 our @ISA = qw(AFS::Command::Base);
-our $VERSION = '1.4';
+our $VERSION = '1.7';
 
 sub examine {
 
@@ -69,12 +69,14 @@ sub examine {
 		  (
 		   id			=> $1,
 		   status		=> 'busy',
+		   attached		=> 1,
 		  );
 	    } elsif ( /Could not attach volume (\d+)/ ) {
 		$header->_setAttribute
 		  (
 		   id			=> $1,
 		   status		=> 'offline',
+		   attached		=> 0,
 		  );
 	    }
 
@@ -82,46 +84,54 @@ sub examine {
 
 	    next;
 
-	} elsif ( /^$args{id}\s+(\d+)\s+(RW|RO|BK)\s+(\d+)\s+K/ ) {
+	} elsif ( /^(\S+)\s+(\d+)\s+(RW|RO|BK)\s+(\d+)\s+K/ ) {
 
 	    my $header = AFS::Object::VolumeHeader->new();
 
-	    if ( /^$args{id}\s+(\d+)\s+(RW|RO|BK)\s+(\d+)\s+K\s+([\w-]+)/ ) {
+	    if ( /^(\S+)\s+(\d+)\s+(RW|RO|BK)\s+(\d+)\s+K\s+([\w-]+)/ ) {
 
 		$header->_setAttribute
 		  (
-		   name			=> $args{id},
-		   id 			=> $1,
-		   type 		=> $2,
-		   size 		=> $3,
+		   name			=> $1,
+		   id 			=> $2,
+		   type 		=> $3,
+		   size 		=> $4,
 		  );
-		$header->_setAttribute( rwrite	=> $1 ) if $2 eq 'RW';
-		$header->_setAttribute( ronly	=> $1 ) if $2 eq 'RO';
-		$header->_setAttribute( backup	=> $1 ) if $2 eq 'BK';
-
-		my $status = $4;
-		$status = 'offline' if $status eq 'Off-line';
-		$status = 'online' if $status eq 'On-line';
-		$header->_setAttribute( status => $status );
-
-	    } elsif ( /^$args{id}\s+(\d+)\s+(RW|RO|BK)\s+(\d+)\s+K\s+used\s+(\d+)\s+files\s+([\w-]+)/ ) {
-
-		$header->_setAttribute
-		  (
-		   name			=> $args{id},
-		   id			=> $1,
-		   type 		=> $2,
-		   size 		=> $3,
-		   files 		=> $4,
-		  );
-		$header->_setAttribute( rwrite	=> $1 ) if $2 eq 'RW';
-		$header->_setAttribute( ronly	=> $1 ) if $2 eq 'RO';
-		$header->_setAttribute( backup	=> $1 ) if $2 eq 'BK';
+		$header->_setAttribute( rwrite	=> $2 ) if $3 eq 'RW';
+		$header->_setAttribute( ronly	=> $2 ) if $3 eq 'RO';
+		$header->_setAttribute( backup	=> $2 ) if $3 eq 'BK';
 
 		my $status = $5;
 		$status = 'offline' if $status eq 'Off-line';
 		$status = 'online' if $status eq 'On-line';
-		$header->_setAttribute( status => $status );
+		$header->_setAttribute
+		  (
+		   status 		=> $status,
+		   attached		=> 1,
+		  );
+
+	    } elsif ( /^(\S+)\s+(\d+)\s+(RW|RO|BK)\s+(\d+)\s+K\s+used\s+(\d+)\s+files\s+([\w-]+)/ ) {
+
+		$header->_setAttribute
+		  (
+		   name			=> $1,
+		   id			=> $2,
+		   type 		=> $3,
+		   size 		=> $4,
+		   files 		=> $5,
+		  );
+		$header->_setAttribute( rwrite	=> $2 ) if $3 eq 'RW';
+		$header->_setAttribute( ronly	=> $2 ) if $3 eq 'RO';
+		$header->_setAttribute( backup	=> $2 ) if $3 eq 'BK';
+
+		my $status = $6;
+		$status = 'offline' if $status eq 'Off-line';
+		$status = 'online' if $status eq 'On-line';
+		$header->_setAttribute
+		  (
+		   status 		=> $status,
+		   attached		=> 1,
+		  );
 
 	    } else {
 
@@ -187,8 +197,8 @@ sub examine {
 		    next;
 		}
 
-		if ( /^\s+(\d+) access/ ) {
-		    $header->_setAttribute( access	=> $1 );
+		if ( /^\s+(\d+) accesses/ ) {
+		    $header->_setAttribute( accesses	=> $1 );
 		    next;
 		}
 
@@ -696,6 +706,7 @@ sub listvol {
 		  (
 		   id			=> $1,
 		   status		=> 'busy',
+		   attached		=> 1,
 		  );
 		$partition->_addVolumeHeader($volume);
 		next;
@@ -704,6 +715,7 @@ sub listvol {
 		  (
 		   id			=> $1,
 		   status		=> 'offline',
+		   attached		=> 0,
 		  );
 		$partition->_addVolumeHeader($volume);
 		next;
@@ -731,12 +743,14 @@ sub listvol {
 		   type			=> $type,
 		   size			=> $size,
 		   status		=> $status,
+		   attached		=> 1,
 		  );
 	    } elsif ( @array == 1 ) {
 		$volume->_setAttribute
 		  (
 		   id			=> $_,
 		   status		=> 'online',
+		   attached		=> 1,
 		  );
 	    } else {
 		$self->_Carp("Unable to parse header summary line:\n" . $_);
@@ -784,8 +798,8 @@ sub listvol {
 			next;
 		    }
 
-		    if ( /^\s+(\d+) access/ ) {
-			$volume->_setAttribute( access => $1 );
+		    if ( /^\s+(\d+) accesses/ ) {
+			$volume->_setAttribute( accesses => $1 );
 			next;
 		    }
 		}		# while(defined($_ = $self->{handle}->getline())) {
