@@ -1,7 +1,7 @@
 #
-# $Id: PTServer.pm,v 5.1 2003/11/05 22:52:39 wpm Exp $
+# $Id: PTServer.pm,v 8.1 2004/05/17 13:04:06 wpm Exp $
 #
-# (c) 2003 Morgan Stanley and Co.
+# (c) 2003-2004 Morgan Stanley and Co.
 # See ..../src/LICENSE for terms of distribution.
 #
 
@@ -10,7 +10,7 @@ package AFS::Object::PTServer;
 use strict;
 
 our @ISA = qw(AFS::Object);
-our $VERSION = '1.4';
+our $VERSION = '1.7';
 
 sub getGroupNames {
     my $self = shift;
@@ -34,7 +34,7 @@ sub getGroupByName {
     my $self = shift;
     my $name = shift;
     return unless ref $self->{_groups} && ref $self->{_groups}->{_byName};
-    return $self->{_groups}->{_byName}->{$name};
+    return $self->{_groups}->{_byName}->{lc($name)};
 }
 
 sub getGroupById {
@@ -66,7 +66,7 @@ sub getGroup {
 
     if ( exists $args{name} ) {
 	return unless ref $self->{_groups} && ref $self->{_groups}->{_byName};
-	return $self->{_groups}->{_byName}->{$args{name}};
+	return $self->{_groups}->{_byName}->{lc($args{name})};
     }
 
 }
@@ -122,7 +122,7 @@ sub getUserByName {
     my $self = shift;
     my $name = shift;
     return unless ref $self->{_users} && ref $self->{_users}->{_byName};
-    return $self->{_users}->{_byName}->{$name};
+    return $self->{_users}->{_byName}->{lc($name)};
 }
 
 sub getUserById {
@@ -154,7 +154,7 @@ sub getUser {
 
     if ( exists $args{name} ) {
 	return unless ref $self->{_users} && ref $self->{_users}->{_byName};
-	return $self->{_users}->{_byName}->{$args{name}};
+	return $self->{_users}->{_byName}->{lc($args{name})};
     }
 
 }
